const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    const vars = context.steps;

    let credential = JSON.parse(Mesa.credential.get('chatgpt'));
    Mesa.log.info("credential: ", credential);

    let options = {
      "headers": {
        "Content-Type": "application\/json",
        "Authorization": "Bearer " + credential.apikey,
      }
    }

    let url = 'https://api.openai.com/v1/chat/completions';

    let content = [];
    content.push({
      "type": "text", 
      "text": vars.transform.prompt
    });

    for (let image of vars.shopify.images) {
      content.push({
        "type": "image_url",
        "image_url": {
          "url": image.src,
        }
      });
    }
      
    let data = {
      "model": "gpt-4-vision-preview",
      "messages": [
        {
          "role": "user",
          "content": content,
        },
      ],
      "max_tokens": 100,
    }

    let result = Mesa.request.post(url, data, options);
    if (result.error) {
      throw new Error(result.error.message)
    }

    Mesa.trigger.setTaskExternalData({
      "label": result.choices[0].message.content,
    })

    Mesa.output.next({"tags": result.choices[0].message.content});
  }
}
